'use client'

import { Portal, Box, useDisclosure, useColorModeValue } from "@chakra-ui/react";
import Footer from "@/components/footer/FooterAdmin";
import Navbar from "@/components/navbar/NavbarAdmin";
import Sidebar from "@/components/sidebar/Sidebar";
import { SidebarContext } from "@/contexts/SidebarContext";
import { PropsWithChildren, useEffect, useState } from "react";
import routes from '@/routes'
import { usePathname } from "next/navigation";
import { useGeneral } from "@/contexts/GeneralContext";
import { getActiveNavbarText, getActiveRoute, getActiveNavbar } from "@/utils/navigation";

interface DashboardLayoutProps extends PropsWithChildren {
  [x: string]: any;
}

export default function RiderLayout({ children, ...rest }: DashboardLayoutProps) {
  const pathname = usePathname();
  const { currentUser } = useGeneral();
  const [toggleSidebar, setToggleSidebar] = useState(false);
  const { onOpen } = useDisclosure();
  const appRoutes = routes(currentUser.roles[0]);
  const bg = useColorModeValue("secondaryGray.300", "navy.900");

  useEffect(() => {
    document.documentElement.dir = "ltr";
  }, []);

  useEffect(() => {
    // Check if Service Worker is supported and register it
    // if ("serviceWorker" in navigator) {
    //   navigator.serviceWorker
    //     .register("/sw.js") // Ensure this matches the service worker path
    //     .then((registration) => {
    //       console.log("Service Worker registered with scope:", registration.scope);
    //       // Force update the service worker after registration
    //       navigator.serviceWorker.getRegistrations().then((registrations) => {
    //         registrations.forEach((registration) => {
    //           registration.update(); // Force update
    //         });
    //       });
    //     })
    //     .catch((error) => {
    //       console.error("Service Worker registration failed:", error);
    //     });
    // }

    // if ("serviceWorker" in navigator && window.serwist !== undefined) {
    //   window.serwist.register();
    // }
  }, []); // Empty dependency array ensures this runs once on mount

  return (
    <Box h="100vh" w="100vw" bg={bg}>
      <SidebarContext.Provider value={{ toggleSidebar, setToggleSidebar }}>
        <Sidebar routes={appRoutes} display="none" {...rest} />
        <Box float="right" minHeight="100vh" overflow="auto" maxHeight="100%" w={{ base: "100%", xl: "calc(100% - 290px)" }}>
          <Portal>
            <Navbar message={getActiveNavbarText(appRoutes, pathname)} onOpen={onOpen} brandText={getActiveRoute(appRoutes, pathname)} secondary={getActiveNavbar(appRoutes, pathname)} fixed={false} {...rest} />
          </Portal>
          <Box mx="auto" p={{ base: "20px", md: "30px" }} pe="20px" minH="100vh" pt="50px">
            {children}
          </Box>
          <Footer />
        </Box>
      </SidebarContext.Provider>
    </Box>
  );
}
